==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit4/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/IndividualResults.java <==
package com.example.model;

/**
 * Model for IndividualResults
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.328Z")
@io.swagger.annotations.ApiModel(value = "IndividualResults", description = "Model for IndividualResults")
@javax.xml.bind.annotation.XmlRootElement(name = "IndividualResults")
public class IndividualResults implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.util.List<java.lang.String> background = new java.util.ArrayList<java.lang.String>();
	private java.util.List<com.example.model.Dvs> dvs = null;
	private com.example.model.Watchlist watchlist = null;
	
	/**
	 */
	public IndividualResults background(java.util.List<java.lang.String> background) {
		setBackground(background);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("background")
	@javax.validation.Valid
	@javax.validation.constraints.NotNull
	public java.util.List<java.lang.String> getBackground() {
		return this.background;
	}
	public void setBackground(java.util.List<java.lang.String> background) {
		this.background = background;
	}
	public IndividualResults addBackground(java.lang.String background) {
		if (this.background == null) {
			this.background = new java.util.ArrayList<java.lang.String>();
		}
		this.background.add(background);
		return this;
	}
	
	/**
	 */
	public IndividualResults dvs(java.util.List<com.example.model.Dvs> dvs) {
		setDvs(dvs);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("dvs")
	@javax.validation.Valid
	public java.util.List<com.example.model.Dvs> getDvs() {
		return this.dvs;
	}
	public void setDvs(java.util.List<com.example.model.Dvs> dvs) {
		this.dvs = dvs;
	}
	public IndividualResults addDv(com.example.model.Dvs dv) {
		if (this.dvs == null) {
			this.dvs = new java.util.ArrayList<com.example.model.Dvs>();
		}
		this.dvs.add(dv);
		return this;
	}
	
	/**
	 * Model for Watchlist
	 */
	public IndividualResults watchlist(com.example.model.Watchlist watchlist) {
		setWatchlist(watchlist);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "Model for Watchlist")
	@com.fasterxml.jackson.annotation.JsonProperty("watchlist")
	@javax.validation.Valid
	public com.example.model.Watchlist getWatchlist() {
		return this.watchlist;
	}
	public void setWatchlist(com.example.model.Watchlist watchlist) {
		this.watchlist = watchlist;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		IndividualResults individualResults = (IndividualResults) o;
		return java.util.Objects.equals(this.background, individualResults.background)
				&& java.util.Objects.equals(this.dvs, individualResults.dvs)
				&& java.util.Objects.equals(this.watchlist, individualResults.watchlist);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.background, this.dvs, this.watchlist);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class IndividualResults {\n");
		
		sb.append("    background: ").append(toIndentedString(this.background)).append("\n");
		sb.append("    dvs: ").append(toIndentedString(this.dvs)).append("\n");
		sb.append("    watchlist: ").append(toIndentedString(this.watchlist)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit4/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/IndividualResults.java <==
package com.example.model;

/**
 * Model for IndividualResults
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.431Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "IndividualResults", description = "Model for IndividualResults")
@javax.xml.bind.annotation.XmlRootElement(name = "IndividualResults")
public class IndividualResults implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.util.List<java.lang.String> background = new java.util.ArrayList<java.lang.String>();
	private java.util.List<com.example.model.Dvs> dvs = null;
	private com.example.model.Watchlist watchlist = null;
	
	/**
	 */
	public IndividualResults background(java.util.List<java.lang.String> background) {
		setBackground(background);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "background")
	@com.fasterxml.jackson.annotation.JsonProperty("background")
	@javax.validation.Valid
	@javax.validation.constraints.NotNull
	public java.util.List<java.lang.String> getBackground() {
		return this.background;
	}
	public void setBackground(java.util.List<java.lang.String> background) {
		this.background = background;
	}
	public IndividualResults addBackground(java.lang.String background) {
		if (this.background == null) {
			this.background = new java.util.ArrayList<java.lang.String>();
		}
		this.background.add(background);
		return this;
	}
	
	/**
	 */
	public IndividualResults dvs(java.util.List<com.example.model.Dvs> dvs) {
		setDvs(dvs);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "dvs")
	@com.fasterxml.jackson.annotation.JsonProperty("dvs")
	@javax.validation.Valid
	public java.util.List<com.example.model.Dvs> getDvs() {
		return this.dvs;
	}
	public void setDvs(java.util.List<com.example.model.Dvs> dvs) {
		this.dvs = dvs;
	}
	public IndividualResults addDv(com.example.model.Dvs dv) {
		if (this.dvs == null) {
			this.dvs = new java.util.ArrayList<com.example.model.Dvs>();
		}
		this.dvs.add(dv);
		return this;
	}
	
	/**
	 * Model for Watchlist
	 */
	public IndividualResults watchlist(com.example.model.Watchlist watchlist) {
		setWatchlist(watchlist);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "watchlist", description = "Model for Watchlist")
	@com.fasterxml.jackson.annotation.JsonProperty("watchlist")
	@javax.validation.Valid
	public com.example.model.Watchlist getWatchlist() {
		return this.watchlist;
	}
	public void setWatchlist(com.example.model.Watchlist watchlist) {
		this.watchlist = watchlist;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		IndividualResults individualResults = (IndividualResults) o;
		return java.util.Objects.equals(this.background, individualResults.background)
				&& java.util.Objects.equals(this.dvs, individualResults.dvs)
				&& java.util.Objects.equals(this.watchlist, individualResults.watchlist);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.background, this.dvs, this.watchlist);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class IndividualResults {\n");
		
		sb.append("    background: ").append(toIndentedString(this.background)).append("\n");
		sb.append("    dvs: ").append(toIndentedString(this.dvs)).append("\n");
		sb.append("    watchlist: ").append(toIndentedString(this.watchlist)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
